@@ -50,7 +50,10 @@ class OpenApiSqliScanner:
         self._headers = CIMultiDict(headers or {})
         self._headers.setdefault(
             'User-Agent',
-            f'Mozilla 5.0 ({__package_name__} v{__version__} +https://github.com/tz4678/openapi-sqli-scanner)',
+            (
+                f'Mozilla 5.0 ({__package_name__} v{__version__}'
+                ' +https://github.com/tz4678/openapi-sqli-scanner)'
+            ),
         )
         logger.debug('User-Agent = %r', self._headers['user-agent'])
         self._rate_limiter = AsyncLimiter(rate_limit or 100)
@@ -94,8 +97,9 @@ class OpenApiSqliScanner:
         data: Optional[dict[str, Any]] = None,
     ) -> aiohttp.ClientResponse:
         async with self._rate_limiter:
+            method = method.upper()
             response = await self._session.request(
-                method.upper(),
+                method,
                 url,
                 params=query,
                 json=data,
